@@ -78,9 +78,9 @@ class TickData(BaseData):
 
     localtime: datetime = None
 
-    def __post_init__(self):
+    def __post_init__(self) -> None:
         """"""
-        self.vt_symbol = f"{self.symbol}.{self.exchange.value}"
+        self.vt_symbol: str = f"{self.symbol}.{self.exchange.value}"
 
 
 @dataclass
@@ -102,9 +102,9 @@ class BarData(BaseData):
     low_price: float = 0.0
     close_price: float = 0.0
 
-    def __post_init__(self):
+    def __post_init__(self) -> None:
         """"""
-        self.vt_symbol = f"{self.symbol}.{self.exchange.value}"
+        self.vt_symbol: str = f"{self.symbol}.{self.exchange.value}"
 
 
 @dataclass
@@ -128,10 +128,10 @@ class OrderData(BaseData):
     datetime: datetime = None
     reference: str = ""
 
-    def __post_init__(self):
+    def __post_init__(self) -> None:
         """"""
-        self.vt_symbol = f"{self.symbol}.{self.exchange.value}"
-        self.vt_orderid = f"{self.gateway_name}.{self.orderid}"
+        self.vt_symbol: str = f"{self.symbol}.{self.exchange.value}"
+        self.vt_orderid: str = f"{self.gateway_name}.{self.orderid}"
 
     def is_active(self) -> bool:
         """
@@ -143,7 +143,7 @@ class OrderData(BaseData):
         """
         Create cancel request object from order.
         """
-        req = CancelRequest(
+        req: CancelRequest = CancelRequest(
             orderid=self.orderid, symbol=self.symbol, exchange=self.exchange
         )
         return req
@@ -167,11 +167,11 @@ class TradeData(BaseData):
     volume: float = 0
     datetime: datetime = None
 
-    def __post_init__(self):
+    def __post_init__(self) -> None:
         """"""
-        self.vt_symbol = f"{self.symbol}.{self.exchange.value}"
-        self.vt_orderid = f"{self.gateway_name}.{self.orderid}"
-        self.vt_tradeid = f"{self.gateway_name}.{self.tradeid}"
+        self.vt_symbol: str = f"{self.symbol}.{self.exchange.value}"
+        self.vt_orderid: str = f"{self.gateway_name}.{self.orderid}"
+        self.vt_tradeid: str = f"{self.gateway_name}.{self.tradeid}"
 
 
 @dataclass
@@ -190,10 +190,10 @@ class PositionData(BaseData):
     pnl: float = 0
     yd_volume: float = 0
 
-    def __post_init__(self):
+    def __post_init__(self) -> None:
         """"""
-        self.vt_symbol = f"{self.symbol}.{self.exchange.value}"
-        self.vt_positionid = f"{self.vt_symbol}.{self.direction.value}"
+        self.vt_symbol: str = f"{self.symbol}.{self.exchange.value}"
+        self.vt_positionid: str = f"{self.vt_symbol}.{self.direction.value}"
 
 
 @dataclass
@@ -208,10 +208,10 @@ class AccountData(BaseData):
     balance: float = 0
     frozen: float = 0
 
-    def __post_init__(self):
+    def __post_init__(self) -> None:
         """"""
-        self.available = self.balance - self.frozen
-        self.vt_accountid = f"{self.gateway_name}.{self.accountid}"
+        self.available: float = self.balance - self.frozen
+        self.vt_accountid: str = f"{self.gateway_name}.{self.accountid}"
 
 
 @dataclass
@@ -223,9 +223,9 @@ class LogData(BaseData):
     msg: str
     level: int = INFO
 
-    def __post_init__(self):
+    def __post_init__(self) -> None:
         """"""
-        self.time = datetime.now()
+        self.time: datetime = datetime.now()
 
 
 @dataclass
@@ -254,9 +254,9 @@ class ContractData(BaseData):
     option_portfolio: str = ""
     option_index: str = ""          # for identifying options with same strike price
 
-    def __post_init__(self):
+    def __post_init__(self) -> None:
         """"""
-        self.vt_symbol = f"{self.symbol}.{self.exchange.value}"
+        self.vt_symbol: str = f"{self.symbol}.{self.exchange.value}"
 
 
 @dataclass
@@ -280,10 +280,10 @@ class QuoteData(BaseData):
     datetime: datetime = None
     reference: str = ""
 
-    def __post_init__(self):
+    def __post_init__(self) -> None:
         """"""
-        self.vt_symbol = f"{self.symbol}.{self.exchange.value}"
-        self.vt_quoteid = f"{self.gateway_name}.{self.quoteid}"
+        self.vt_symbol: str = f"{self.symbol}.{self.exchange.value}"
+        self.vt_quoteid: str = f"{self.gateway_name}.{self.quoteid}"
 
     def is_active(self) -> bool:
         """
@@ -295,7 +295,7 @@ class QuoteData(BaseData):
         """
         Create cancel request object from quote.
         """
-        req = CancelRequest(
+        req: CancelRequest = CancelRequest(
             orderid=self.quoteid, symbol=self.symbol, exchange=self.exchange
         )
         return req
@@ -310,9 +310,9 @@ class SubscribeRequest:
     symbol: str
     exchange: Exchange
 
-    def __post_init__(self):
+    def __post_init__(self) -> None:
         """"""
-        self.vt_symbol = f"{self.symbol}.{self.exchange.value}"
+        self.vt_symbol: str = f"{self.symbol}.{self.exchange.value}"
 
 
 @dataclass
@@ -330,15 +330,15 @@ class OrderRequest:
     offset: Offset = Offset.NONE
     reference: str = ""
 
-    def __post_init__(self):
+    def __post_init__(self) -> None:
         """"""
-        self.vt_symbol = f"{self.symbol}.{self.exchange.value}"
+        self.vt_symbol: str = f"{self.symbol}.{self.exchange.value}"
 
     def create_order_data(self, orderid: str, gateway_name: str) -> OrderData:
         """
         Create order data from request.
         """
-        order = OrderData(
+        order: OrderData = OrderData(
             symbol=self.symbol,
             exchange=self.exchange,
             orderid=orderid,
@@ -363,9 +363,9 @@ class CancelRequest:
     symbol: str
     exchange: Exchange
 
-    def __post_init__(self):
+    def __post_init__(self) -> None:
         """"""
-        self.vt_symbol = f"{self.symbol}.{self.exchange.value}"
+        self.vt_symbol: str = f"{self.symbol}.{self.exchange.value}"
 
 
 @dataclass
@@ -380,9 +380,9 @@ class HistoryRequest:
     end: datetime = None
     interval: Interval = None
 
-    def __post_init__(self):
+    def __post_init__(self) -> None:
         """"""
-        self.vt_symbol = f"{self.symbol}.{self.exchange.value}"
+        self.vt_symbol: str = f"{self.symbol}.{self.exchange.value}"
 
 
 @dataclass
@@ -401,15 +401,15 @@ class QuoteRequest:
     ask_offset: Offset = Offset.NONE
     reference: str = ""
 
-    def __post_init__(self):
+    def __post_init__(self) -> None:
         """"""
-        self.vt_symbol = f"{self.symbol}.{self.exchange.value}"
+        self.vt_symbol: str = f"{self.symbol}.{self.exchange.value}"
 
     def create_quote_data(self, quoteid: str, gateway_name: str) -> QuoteData:
         """
         Create quote data from request.
         """
-        quote = QuoteData(
+        quote: QuoteData = QuoteData(
             symbol=self.symbol,
             exchange=self.exchange,
             quoteid=quoteid,
